Index: chrome/browser/io_thread.cc |
diff --git a/chrome/browser/io_thread.cc b/chrome/browser/io_thread.cc |
index 1067bf8f5a5b8893cd372715614b69fa4cec1ba2..94d31262f4e91c278c58d628b60854270b6a55ff 100644 |
--- a/chrome/browser/io_thread.cc |
+++ b/chrome/browser/io_thread.cc |
@@ -343,7 +343,7 @@ void IOThread::Init() { |
void IOThread::CleanUp() { |
// Step 1: Kill all things that might be holding onto |
- // URLRequest/URLRequestContexts. |
+ // net::URLRequest/URLRequestContexts. |
#if defined(USE_NSS) |
net::ShutdownOCSP(); |
@@ -437,12 +437,12 @@ void IOThread::CleanUpAfterMessageLoopDestruction() { |
// anything else can reference it. |
BrowserProcessSubThread::CleanUpAfterMessageLoopDestruction(); |
// URLRequest instances must NOT outlive the IO thread. |
// |
// To allow for URLRequests to be deleted from |
// MessageLoop::DestructionObserver this check has to happen after CleanUp |
// (which runs before DestructionObservers). |
- base::debug::LeakTracker<URLRequest>::CheckForLeaks(); |
+ base::debug::LeakTracker<net::URLRequest>::CheckForLeaks(); |
} |
// static |
@@ -437,12 +437,12 @@ void IOThread::CleanUpAfterMessageLoopDestruction() { |
// anything else can reference it. |
BrowserProcessSubThread::CleanUpAfterMessageLoopDestruction(); |
- // URLRequest instances must NOT outlive the IO thread. |
+ // net::URLRequest instances must NOT outlive the IO thread. |
// |
// To allow for URLRequests to be deleted from |